package org.dvb.application.privileged;

import org.dvb.xml.jdom.Element;

/**
 * Provides application management features and capabilities only appropriate
 * for privileged applications.
 * On systems where this class is supported, org.ocap.application.AppManagerProxy.getInstance
 * shall return an instance of ApplicationStorageManager.
 */

public class ApplicationStorageManager extends org.ocap.application.AppManagerProxy {
	/**
	 * This constructor is not to be used by applications.
	 */
	protected ApplicationStorageManager() {}

	/**
 	 * Registers an ApplicationStorageHandler to become part of decisions
	 * about permitting the storing and removing of applications and services
	 * using the facilities provided by the org.dvb.application.storage package.
	 * Only one handler can be registered at one time hence multiple calls to
	 * this method shall replace the handler set in the previous call.
	 * No handler being set shall be equivalent to a handler which always
	 * permits requests to succeed.
	 *
	 * @param handler either an ApplicationStorageHandler or null
	 * to remove the current handler if one is set
	 * @throws SecurityException if the calling application does not have
	 * MonitorAppPermission("registrar")
	 */
	public void setApplicationStorageHandler( ApplicationStorageHandler handler )
	{}
	
	/**
 	 * Registers new unbound application entries.
	 *
	 * @param element an ApplicationList element containing
	 * the new or updated XAIT information
	 * @throws SecurityException if the caller does not have 
	 * MonitorAppPermission("registrar")
	 * @throws IllegalArgumentException if the element is not 
	 * a root element whose value is "ApplicationList"
	 */
	public void registerUnboundApp( Element element ){}
}

