package org.dvb.hardware;

/**
 * Provides access to low level details of the GEM terminal.
 */

public class Terminal {
	/**
	 * This constructor is provided for the use of implementations and
	 * specifications which extend this specification. Applications shall not
	 * define sub-classes of this class. Implementations are not required to
	 * behave correctly if any such application defined sub-classes are used.
	 */
	protected Terminal() {}

	/**
	 * Initiates a reset of the GEM terminal equivalent to a power cycle.
	 * The method SystemEventListener.notifyEvent(SystemEvent) shall be called
	 * before the reboot is performed by the GEM terminal. Once the
	 * notifyEvent method returns, the reboot process shall continue. If the
	 * notify event method does not return within an implementation dependent
	 * time then the reboot process may continue regardless.
	 * @throws SecurityException if the caller does not have
	 * MonitorAppPermission("reboot")
	 */
	public void reset(){}

	/**
	 * Re-initializes the GEM software environment including re-initializing
	 * all DVB-J virtual machine or machines and re-starting all GEM
 	 * applications.
	 * The method SystemEventListener.notifyEvent(SystemEvent) shall be called
	 * before the re-initialization is performed by the GEM terminal. Once the
	 * notifyEvent method returns, the process shall continue. If the
	 * notify event method does not return within an implementation dependent
	 * time then the process may continue regardless.
	 * @throws SecurityException if the caller does not have
	 * MonitorAppPermission("reboot")
	 */
	public void reinitialize(){}

	/**
	 * Set the time that the system shall wait for the
	 * SystemEventListener.notifyEvent(SystemEvent) to return before
	 * it shall continue regardless. If not set then the default is
	 * implementation dependent.
	 * @param seconds the time to wait in seconds
	 * @throws SecurityException if the caller does not have
	 * MonitorAppPermission("reboot")
	 */
	public void setRebootTimeout( int seconds ){}

	/**
	 * Get the time that the system shall wait for the
	 * SystemEventListener.notifyEvent(SystemEvent) to return before
	 * continuing regardless.
	 * @return the reboot timeout measured in seconds
	 */
	public int getRebootTimeout() { return 0;}

	/**
	 * Return a human-readable string identifying this terminal. This should
	 * be in a format that could be read during a phone call to an operator.
	 * @return the host identifier
	 */
	public java.lang.String getID() { return null;}
}

