package org.dvb.locator.ip;
/**
 * Represents a reference to an IP service delivered by unicast UDP
 * where the delivery of the service is not initiated by the
 * implementation. The only requirement on implementations
 * when locators of this type are used is to listen
 * on the specified port number for content to arrive.<p>
 * The intended use case for this locator is as follows
 * <ul>
 * <li>the application picks a local port number
 * <li>the application uses this locator to tell the 
 * implementation to listen for an IP service delivered on
 * that local port number
 * <li>the application obtains the IP address of the device
 * on which it's running - e.g. via java.net.NetworkInterface
 * <li>the application passes that port number and the IP
 * address to a VoD server as part of a request for some
 * content.
 * <li>the VoD server delivers the requested content to
 * the specified IP address and port
 * <li>the implementation detects the arrival of the content
 * on the port and starts processing and presenting it
 * </ul>
 * The external form of this locator is not defined by the 
 * present document.<p>
 */
public class UnicastLocator extends org.davic.net.Locator {
	/**
	 * Creates a <code>UnicastLocator</code> from the specified local port number.
	 * @param port the local port number on which the content will be delivered
	 */
	public UnicastLocator ( int port )
	{
		super("");
	}
	/**
	 * Creates a <code>UnicastLocator</code> from the specified local port number and service ID.
	 * @param port the local port number on which the content will be delivered
  	 * @param serviceID a DVB-SI serviceID or MPEG program number to identify
 	 * one service in a multi-program transport stream
	 * @exception java.net.MalformedURLException if the port number is not valid
	 * @exception IllegalArgumentException if the service ID is less than 0 or greater than 0xffff
	 */
	public UnicastLocator ( int port, int serviceID ) throws java.net.MalformedURLException, IllegalArgumentException
	{
		super("");
	}

 	/**
	 * Returns the port specified when this <code>UnicastLocator</code> 
	 * was constructed.
	 * @return the port specified when this <code>UnicastLocator</code> 
	 * or -1 if no port was specified
	 */
	public int getPort() {return 0;}

 	/**
	 * Returns the serviceID specified when this <code>UnicastLocator</code> 
	 * was constructed.
	 * @return the serviceID specified when this <code>UnicastLocator</code> 
	 * or -1 if no serviceID was specified
	 */
	public int getServiceID() {return 0;}
}

