/**

 *
 */
package org.dvb.media;

import java.util.EventObject;
import javax.media.Controller;
import javax.media.Player;

/**
 * An event which indicates change of status of synchronization between master/slave JMF Players.
 * <BR><BR>
 * This event is generated by MasterSlaveSyncLinkageControl object when status of synchronization between
 * any combination of the master Player and slave Players.<BR>
 *
 */
public class SyncStateChangedEvent extends EventObject {
	private int aStatus;
	private SyncControl aSC;
	private Controller aCtrl = null;

	/**
	 * Constructs a SyncStateChangedEvent object.
	 * @param ctrl Controller object of a slave Player that is related to this object.
	 * @param status current status of synchronization as a result of its change.
	 * @see org.dvb.media.MasterSlaveSyncLinkageControl#IN_SYNC Fields in SyncControl
	 */
	public SyncStateChangedEvent(Object source, Controller ctrl, int status) {
		super(source);
		aStatus = status;
		aCtrl = ctrl;
	}

	/**
	 * Gets Controller object of a slave JMF Player object that is related to this event.
	 * @return A slave Player object related to this event object.
	 */
	public Controller getSourceController() {
		return aCtrl;
	}


	/**
	 * Gets changed synchronization status.
	 * @return changed synchronization status.
	 */
	public int getSyncStatus() {
		return aStatus;
	}

}
