/**
 *
 */
package org.dvb.media;

import java.util.EventListener;

/**
 * This listener interface is for receiving synchronization change events among
 * JMF Players. The class that is interested in management of synchronization
 * among JMF Players is registered with MasterSlaveSyncLinkageControl object using
 * addSyncStateChangedEventListener method. The event is generated when synchronization
 * status among JMF Players is changed. The relevant method in the
 * listener object is then invoked, and the SyncStateChangedEvent is passed to it.
 *
 */
public interface SyncStateChangedEventListener extends EventListener {

	/**
	 * Invoked when any combination of master and slave Players are synchronized.
	 */
	public void inSync(SyncStateChangedEvent e);

	/**
	 * Invoked when any combination of master and slave Players are desynchronized.
	 */
	public void outOfSync(SyncStateChangedEvent e);

	/**
	 * Invoked when synchronization is never established.
	 */
	public void unSynchronizable(SyncStateChangedEvent e);
}
