package org.dvb.media.monitoring;

/**
 * Event is signalling that quality of the associated CoD has been
 * changed. <BR>
 * <BR>
 * This event shall occur when adaptive streaming changes played stream to
 * another stream with a different video resolution and/or stream's
 * bitrate because of changing network conditions.
 * 
 */
public class StreamQualityChangeEvent extends MonitoringEvent {

   private static final long serialVersionUID = -4657315133893871930L;

   private StreamQualityInfo streamQuality;

   /**
    * Construct the event.
    * 
    * @param source
    *           the source of the event. The platform shall always pass in the
    *           JMF Player presenting the media whose property has been changed
    * @param newStreamQuality
    *           the new value of quality of the stream
    * 
    */
   public StreamQualityChangeEvent(Object source, StreamQualityInfo newStreamQuality) {
      super(source);
      streamQuality = newStreamQuality;
   }

   /**
    * Get the new quality of associated CoD.
    * 
    * @return the new stream's quality
    * 
    */
   public StreamQualityInfo getStreamQuality() {
      return streamQuality;
   }
}
