package org.dvb.media.monitoring;

import java.awt.Dimension;

/**
 * Represent information about quality of a video CoD stream. It contains
 * information about video resolution and stream bitrate (bits per second). <BR>
 * <BR>
 * Instance of this class shall be returned by
 * {@link MonitoringControl#getAvailableStreamQualities()} and
 * {@link MonitoringControl#getStreamQuality()} in case when video stream is
 * playing. Additionally, in this case an instance of this class shall be passed
 * to {@link MonitoringControl#setFixedStreamQuality(StreamQualityInfo)} and
 * {@link MonitoringControl#setFixedStreamQuality(StreamQualityInfo)} methods.
 * 
 */
public class VideoStreamQualityInfo extends StreamQualityInfo {
   private Dimension videoResolution;

   /**
    * Construct an stream quality entity.
    * 
    * @param videoResolution
    *           video resolution
    * @param bitrate
    *           stream bitrate
    */
   public VideoStreamQualityInfo(java.awt.Dimension videoResolution, long bitrate) {
      super(bitrate);
      this.videoResolution = videoResolution;
   }

   /**
    * Get video resolution of a CoD.
    * 
    * @return video resolution of a CoD
    */
   public java.awt.Dimension getVideoResolution() {
      return videoResolution;
   }
}
