package org.dvb.service.navigation;

import javax.tv.service.Service;

/**
 * CompatibleServiceFilter represents a ServiceFilter based on the
 * capabilities of the receiver. 
 * A ServiceList resulting from this filter will include only services
 * which are compatible with this receiver. 
 * <ul>
 * <li>If the service is scrambled by a conditional access system or
 * equivalent, the service is only compatible if the receiver would
 * be able to descramble the service given appropriate rights or
 * entitlements.
 * <li>If the service includes one or more streams of type video, it
 * is only compatible if the receiver can decode at least one stream.
 * <li>If the service includes one or more streams of type audio, it
 * is only compatible if the receiver can decode at least one stream.
 * </ul>
 */
public final class CompatibleServiceFilter extends javax.tv.service.navigation.ServiceFilter
{
	/**
	 * Constructs the filter 
	 */
	public CompatibleServiceFilter( )
	{
		super();
	}

	/**
	 * Tests if the given service passes the filter.
	 *
	 * @param service An individual <code>Service</code> to be evaluated 
	 * against the filtering algorithm. 
	 * @return true if service is compatible with this receiver; false otherwise
	 */
	public boolean accept(Service service) { return true ;}

}

