package org.dvb.service.sds;

/**
 * This interface provides access to Service Discovery and Selection 
 * Service Provider and Service Offering Records.
 * It is intended to be implemented by an instance of org.dvb.service.SIManager.
 */

public interface SDSRecordAccess
{	
	/** 
	 * Provides access to the SD&S Service Provider records
	 * @return an array of SD&S Service Provider Records
	 */
	public abstract org.dvb.xml.jdom.Element[] getServiceProviderRecords();

	/** 
	 * Provides access to the SD&S Service Offering records for a particular Service Provider
	 * @param domainName Domain name of the service provider for which offerings are requested
	 * @return an array of SD&S Service Offering Records, including BCG records
	 */
	public abstract org.dvb.xml.jdom.Element[] getServiceOfferingRecords(String domainName);

	/**
	 * Register a listener for events based on  changes to SD&S records
	 * @param listener the SDS Record Listener to be registered
	 */
	public abstract void addSDSRecordListener(SDSRecordChangeListener listener);

	/**
	 * Removes a listener for events based on  changes to SD&S records
	 * @param listener the SDS Record Listener to be removed
	 */
	public abstract void removeSDSRecordListener(SDSRecordChangeListener listener);
}

