package org.dvb.service.sds;

import org.dvb.xml.jdom.Element;

/**
 * A SDSRecordEvent notifies an SDSRecordListener of changes detected in SD&S records.
 * Specifically, this event signals the addition, removal, or modification of an SD&S record.
 */

public abstract class SDSRecordChangeEvent extends java.util.EventObject
{
	private javax.tv.service.SIChangeType		type;
	private Element	sdsRecord;

	/**
	 * Constructs an <code>SDSRecordChangeEvent</code> object
	 * @param siManager the SIManager on which the Event initially occurred
	 * @param type the type of change that occured
	 * @param sdsRecord the SD&S record in which the change occurred
	 */
	public SDSRecordChangeEvent( org.dvb.service.DvbSIManager siManager, javax.tv.service.SIChangeType type, Element sdsRecord) 	{
		super(siManager);
	}

	/**
	 * Returns the type of change that occurred
	 * @return SIChangeType the type of change that occurred
	 */
 	public javax.tv.service.SIChangeType getChangeType() {
		return this.type;
	}

	/**
	 * Returns the SD&S record in which the change occured
	 * @return Document XML document of the SD&S record in which the change occurred
	 */
	public Element getSDSRecord() {
		return this.sdsRecord;
	}
}

