package org.dvb.smartcard;

import javax.microedition.io.ConnectionNotFoundException;
import java.io.IOException;
import javax.microedition.apdu.APDUConnection;
/**
 *  Represents a physical smart card reader slot in the terminal.
 * @since MHP 1.1.3
 */
public class SmartCardReader {

    /**
    * This constructor is provided for the use of implementations and specifications
    * which extend this specification. Applications shall not define sub-classes of
    * this class. Implementations are not required to behave correctly if any such
    * application defined sub-classes are used.
    */

  protected SmartCardReader() {
  }

  /**
   * Each single reader is identified on the terminal with an increasing identifier.
   * Default identifier for single slot terminals is zero.
   *
   * @return int id associated to the reader
   */
  public int getSlotId() {
    return 0;
  }

  /**
   * Retrieves current status of the smart card reader.
   * The constant values are the ones defined in SmartCardReaderEvent.
   *
   * @return int current status of the reader
   */
  public int getStatus() {
    return 0;
  }

  /**
   * Allows applications to query if a smart card is inserted in the reader.
   * True is returned also if no ATR is correctly retrieved (i.e. smart card inserted
   * upside-down).
   *
   * @return boolean true if smart card is inserted in given slot
   */
  public boolean isSmartCardInserted() {
    return false;
  }

  /**
   * Allows the specified listener to received notifications about changes in the
   * status of the smart card reader.
   *
   * @param listener the SmartCardReaderListener that will receive the notifications
   */
  public void addSmartCardReaderListener(SmartCardReaderListener listener) {
    return;
  }

  /**
  * Removes specified listener: the notifications about changes in the status of the
  * smart card reader will no longer be forwarded to the given listener.
  *
  * @param listener the SmartCardReaderListener that was receiving the notifications.
  */
  public void removeSmartCardReaderListener(SmartCardReaderListener listener) {
    return;
  }

/**
 * Opens a raw APDU connection without selecting an application or managing channels.
 * The following properties shall apply to raw connections.
 * <ul>
 * <li>There may be only one raw connection open at the same time with 
 * the same smart card.
 * <li>The implementation shall open the connection without sending any extra commands. 
 * <li>A GEM application is allowed to send Application Selection 
 * (SELECT FILE by DF NAME) and MANAGE CHANNEL commands.
 * <li>For the T=0 protocol, for case 4 and case 2 command APDUs the card may respond
 * with ’61 XX’ or ’6C XX’ statuses. The implementation should not handle these
 * special cases, it should neither send GET RESPONSE, nor resend commands.
 * The GEM application is required to handle these cases.
 * </ul>
 *
 * @return an APDUConnection with the selected smartcard
 * @throws SecurityException if the application does not have APDUPermission
 * @throws ConnectionNotFoundException if either the smartcard is not
 * inserted or if opening a connection is not permitted (e.g. for CA cards)
 * @throws IOException if an APDU connection is already open or if any
 * other I/O error occurs
 */

 public APDUConnection openRawConnection() throws IOException, ConnectionNotFoundException {
   return null;
 }



}

