package org.dvb.spi.ict;

import java.util.EventListener;

/**
 * This interface should be implemented by classes within the
 * GEM implementation that will be used as listeners for
 * asynchronous loading of resources by interaction channel
 * transport service providers.
 * <p>
 * Note that in the case where a DVB-J application calls
 * asynchronousLoad() on a DSMCCObject that refers to an
 * interaction channel file system file, the GEM implementation will be
 * responsible for mapping receiveEvent method calls from this
 * method to calls on the corresponding
 * AsynchronousLoadingEventListener (i.e. applications will not
 * be able to reference the service provider classes directly).
 */
public interface AsyncResourceLoadListener extends EventListener {
    /**
     * Notify this listener of an update in the progress of loading
     * a network resource.  The specified event object contains
     * detailed information about the update.
     * 
     * @param e the event object containing details of the update
     */
    public void receiveEvent(AsyncResourceLoadEvent e);
}

