package org.dvb.spi.ict;

import java.util.EventObject;

/**
 * Event indicating that the load of a resource failed.
 */
public final class LoadFailedEvent extends AsyncResourceLoadEvent {
    private Exception reason;

    /**
     * Construct a new event indicating failure to load a resource.
     * 
     * @param source The ResourceTransportObject that was the source
     *               of the failure
     * @param reason Exception indicating the reason for the failure
     *               (may be null)
     */
    public LoadFailedEvent(ResourceTransportObject source, Exception reason) {
        super(source, false);
        this.reason = reason;
    }

    /**
     * Return the reason for the load failure.
     * 
     * @return Exception - The exception object indicating the
     *         reason for the failure (may be null)
     */
    public Exception getReason() {
        return reason;
    }
}

