package org.dvb.spi.ict;

/**
 * Event object used to notify update listeners that a network
 * resource has changed (i.e. a new version is available).
 */
public class ResourceObjectUpdateEvent extends java.util.EventObject {
    private int newVersion;

    /** 
     * Create a ResourceObjectUpdateEvent indicating that a new
     * version of the resource has been detected.  Note that the new
     * version of the resource is not automatically downloaded; that
     * is left to the user of this object.
     * <p>
     * @param source the ResourceTransportObject whose version has
     *               changed
     * @param newVersion the new version number.
     */
    public ResourceObjectUpdateEvent(ResourceTransportObject source, int newVersion) {
        super(source);
        this.newVersion = newVersion;
    }

    /**
     * Return the newly available resource version number (i.e. the
     * version that would be downloaded now if the resource were
     * loaded again).
     * 
     * @return int - the new version number
     */
    public int getNewVersion() {
        return newVersion;
    }
}

