package org.dvb.spi.ict;

/**
 * This interface will be implemented by listeners that are part
 * of the GEM implementation so that they are notified of
 * updates to resources downloaded by an interaction channel
 * tranport service provider.
 * <p>
 * Note that in the case where a DVB-J application registers an
 * ObjectChangeEventListener on a DSMCCObject that refers to an
 * interaction channel file system file, the GEM implementation
 * will be responsible for mapping update method calls from
 * this method to calls to the ObjectChangeEventListener (i.e.
 * applications will not be able to reference the service
 * provider classes directly).
 */
public interface ResourceUpdateListener {
    /**
     * Notify the listener that a downloaded resource object has
     * been updated. Details of the update are described in the
     * specified event object.
     * 
     * @param e the event object describing the change.
     */
    void resourceObjectUpdated(ResourceObjectUpdateEvent e);
}

