package org.dvb.spi.si.simple;

import java.util.Date;
import org.dvb.spi.util.MultilingualString;

/**
 * Encapsulates the description of a program.
 * One instance of ProgramDescription represents a static snapshot
 * of the information about a single program.
 * <p>
 * The program descriptions may be relatively large. Implementations
 * with limited memory resources should be careful not to ask for
 * many descriptions at one time and not to keep references to
 * descriptions longer than needed.
 */

public interface ProgramDescription {

	/**
	 * Return the name of the program.
	 * @return the name 
	 * @param preferredLanguage the preferred language for the name
	 */
	public MultilingualString getName(String preferredLanguage);

	/**
	 * Return the description of the program.
	 * @return the description
	 * @param preferredLanguage the preferred language for the description
	 */
	public MultilingualString getDescription(String preferredLanguage);

	/**
	 * Return the start time for the program.
	 * @return the start time
	 */
	public Date getStartTime();

	/**
	 * Return the end time for the program.
	 * @return the end time
	 */
	public Date getEndTime();
}

