package org.dvb.tvanytime.metadata;

/**
* Class representing a TV-Anytime classification scheme. A classification scheme lists a set 
* of termIDs and allows the corresponding ControlledTerms to be obtained.
*
*/
public abstract class ClassificationScheme {
	
/**
 * This constructor is provided for implementations and should not be used by GEM applications.
 */
  protected ClassificationScheme() {}

/**
* Get an instance of a inbuilt ClassificationScheme which is supported by the platform.
* @param uri The URI or the alias name of the inbuilt classification scheme. 
* @return a ClassificationScheme instance.
* @throws DatabaseException if the specified URI is not supported or the alias cannot be resolved
*/
  public static org.dvb.tvanytime.metadata.ClassificationScheme getInstance(java.lang.String uri) throws DatabaseException {
  	return (null);
  }

  /**
  * Get an instance of a ClassificationScheme referenced by the specified database. 
  * 
  * <p>If the reference includes an alias the method will first attempt to resolve this against CSAlias information 
  * provided by the database. If this fails it will attempt to resolve it against aliases used for the inbuilt 
  * Classication Schemes. If this fails the method will throw a {@link DatabaseException}.
  * 
  * <p>If the resolved reference refers to a Classification Scheme that is not supported by the platform the 
  * method will try to obtain a downloadable Classification Scheme from the database.  If this fails the method 
  * will throw a {@link DatabaseException}.
  *  
  * @param database the metadata service from which the reference was obtained.
  * @param uri the URI or alias name of a classification scheme referenced by the database. 
  * @return a ClassificationScheme.
  * @throws DatabaseException if the reference cannot be resolved or the required ClassificationScheme cannot be found.
  */
  public static org.dvb.tvanytime.metadata.ClassificationScheme getInstance(Database database, java.lang.String uri) throws DatabaseException {
    return (null);
  }
  
  /**
   * Get a ControlledTerm object corresponding to a termID. 
   * @param termID a String that contains the name of the termID 
   * @return a ControlledTerm object
   * @throws DatabaseException if the termID is not found in this ClassificationScheme
   */
   public  abstract ControlledTerm getControlledTerm(java.lang.String termID) throws DatabaseException ;

  /**
   * Get a ControlledTerm object corresponding to a reference obtained from the specified database.
   * 
   * <p>If the reference includes an alias the method will first attempt to resolve this against <code>CSAlias</code> 
   * information provided by the database. If this fails it will attempt to resolve it against aliases used for the 
   * inbuilt Classication Schemes. If this fails the method will throw a {@link DatabaseException}.
   * 
   * <p>If the resolved reference refers to a Classification Scheme that is not supported by the platform the 
   * method will try to obtain a downloadable Classification Scheme from  the database.  If this fails the method 
   * will throw a {@link DatabaseException}.
   * 
   * @param database the database from which the reference was obtained.
   * @param href a reference to a Controlled Term
   * @return a ControlledTerm object
   * @throws DatabaseException  if the reference cannot be resolved, or the required Classification Scheme cannot be 
   * found, or the termID is not found in the ClassificationScheme.
   */
  public static ControlledTerm getControlledTerm(Database database, java.lang.String href) throws DatabaseException 
    {return null;}
     
  /**
   * Get the termIDs supported by this ClassificationScheme.
   * @return an enumeration of the termIDs.
   */
  public abstract java.util.Enumeration getTermIDs();
    
//   /**
//   * For downloadable Classification Schemes this method gives a hint to the GEM that if this object is not 
//   * consumed by another application/thread, the system can free all the resources allocated to this object. 
//   * Once <code>unload()</code> has been called, an application must not call any methods in this object.
//   */
//  public abstract void unload();
  
}
 
