package org.dvb.tvanytime.metadata;

/**
* Interface for encapsulating one term from a classification scheme. 
*/
public abstract interface ControlledTerm   {

/**
* Get the termID of this controlled term. This is the ID that will be found 
* in a TV Anytime metadata document. For example, for the controlled term representing:
* <p>&nbsp;&nbsp;&nbsp;&nbsp;&lt;Genre href="urn:tva:metadata:cs:ContentCS:2002:3.4.11"&gt;
* <p> the getID() function will return "3.4.11" 
* @return a String representing the termID
*/
  public  abstract java.lang.String getID(
  ) ;

/**
* Get the names of this controlled term. There may be multiple names, to 
* allow for names in multiple languages. Using the example from getID(), the 
* getName() function will return {text="Comedy", lang="en"}
* @return an array of Mpeg7Text objects representing a name
*/
  public  abstract org.dvb.tvanytime.metadata.Mpeg7Text[] getName(
  ) ;

/**
* Get the name of a controlled term in the specified language. 
* @param locale the Locale of the language to request (e.g. "de") 
* @return the name (in the requested language) or null if a name is not 
* available in the requested language.
*/
  public  abstract java.lang.String getName(
      java.util.Locale locale
  ) ;

/**
* Get the description of this controlled term. There may be multiple 
* definitions, to allow for descriptions in multiple languages. E.g. 
* {text="Drama in a humourous style", lang="en"}
* @return an array of Mpeg7Text objects carrying a description
*/
  public  abstract org.dvb.tvanytime.metadata.Mpeg7Text[] getDefinition(
  ) ;

/**
* Get the definition of a controlled term in the specified language. 
* @param locale The Locale of the language to request (e.g. "de") 
* @return the definition (in the requested language) or null if a name is not 
* available in the requested language. 
*/
  public  abstract java.lang.String getDefinition(
      java.util.Locale locale
  ) ;

/**
* Get the URI scheme of the classification scheme that this controlled term 
* belongs to. E.g. "urn:tva:metadata:cs:ContentCS:2002"
* @return the URI scheme
*/
  public  abstract java.lang.String getClassificationScheme(
  ) ;

}


