package org.dvb.tvanytime.metadata;

/**
 * Class representing the desired scope of a metadata database. In DVB systems the scope of a metadata service is
 * defined by the locations in which a Metadata Pointer Descriptor can be found. Optionally, it is possible to 
 * restrict the scope to a specific set of fragment types.
 * 
 */
public class DatabaseScope {
	
  /**
   * The value of contextIdType when the contextId is a bouquet_id.
   */
  public static final int BOUQUET_ID = 0x00;

  /**
   * The value of contextIdType when the contextId is an original_network_id.
   */
  public static final int ORIG_NET_ID = 0x01;

  /**
   * The value of contextIdType when the contextId is a network_id.
   */
  public static final int NETWORK_ID = 0x02;
	
  /**
   * Create a DatabaseScope that encompasses a specified CRID authority.
   * @param crid the authority field is taken from the supplied CRID
   */
  public DatabaseScope(org.dvb.tvanytime.resolution.CRID crid) {
  	
  }

  /**
   * Create a DatabaseScope that encompasses a specified resolution provider.
   * @param resolutionProvider the name of the resolutionProvider
   */
  public DatabaseScope(java.lang.String resolutionProvider) {
  	
  }

  /**
   * Create a DatabaseScope that encompasses a specified DVB service.
   * @param service a DVB locator that identifies the DVB service
   */
  public DatabaseScope(org.davic.net.dvb.DvbLocator service) {

  }
 
  /**
   * Create a DatabaseScope that encompasses a specified contextId and contextIdType. These fields are used in the
   * Resolution Notification Table defined in ETSI TS 102 323 where appropriate metadata services may be identified by
   * a Metadata Pointer Descriptor. In the case where the contextId is network_id or a bouquet_id appropriate 
   * metadata services may also be identified by a Metadata Pointer Descriptor in the NIT or BAT respectively.
   * @param contextId the contextId
   * @param contextIdType a value selected from <code>NETWORK_ID</code>, <code>ORIG_NET_ID</code> and <code>BOUQUET_ID</code>.
   * 
   */
  public DatabaseScope (int contextId, int contextIdType) {
  	
  }
  
  /**
   * Set the required fragment types. The supplied values are compared against the optional list of 
   * <code>fragment_type</code> values that may be carried in a Metadata Pointer Descriptor. If none of 
   * the required values are present, or if this list is not available (i.e. the <code>fragment_types_flag</code> 
   * of the descriptor is set to '0') then a DVBDatabase will be considered to be out of scope.
   * 
   * @param fragmentTypes an array of <code>fragment_type</code> values, as specified in ETSI TS 102 323.
   */
  public void setFragmentTypes (int[] fragmentTypes) {}
  	
  /**
   * Get the required fragment types of this DatabaseScope.
   * 
   * @return an array of <code>fragment_type</code> values, as specified in ETSI TS 102 323.
   */
  public int[] getFragmentTypes () {return null;}

}

