package org.dvb.tvanytime.metadata;

/**
* Class providing access to a TV Anytime metadata service that is broadcast in a DVB service. A 
* new instance of this class is required for each of the metadata services 
* that a client wishes to access.
* 
* TV-Anytime metadata fragments obtained from a DVBDatabase shall include fragmentVersion 
* and fragmentId attributes values which are obtained from the encapsulation structure 
* defined in ETSI TS 102 822-3-2 clause 4.6.1.1.
*/
public abstract class DvbDatabase  implements org.dvb.tvanytime.metadata.MonitoredDatabase {

  protected DvbDatabase(
  ) {}

/**
* Get an instance of a DvbDatabase where the platform chooses a DVB service that contains a metadata service.
* 
* <p>If the receiver does not have a DVB tuner a {@link DatabaseException} will be thrown.
* 
* <p>Applications can use the <code>doNotTune</code> parameter to specify that the tuning of a reserved tuner 
* should not be required to access the database. In this case, an <code>org.davic.mpeg.TuningException</code> will 
* be thrown if the platform is unable to provide a DvbDatabase that can be accessed without tuning. 
* If a DvbDatabase is returned but subsequently becomes inaccessible without tuning a {@link DatabaseException} 
* will be thrown if access is attempted.
* 
* <p>If the <code>doNotTune</code> parameter is set to false and tuning is required to access the database then a 
* tuner will be reserved if one is available. If a tuner cannot be reserved then a <code>org.davic.mpeg.TuningException</code> 
* will be thrown.
*  
* @param doNotTune true indicates that tuning must not be required to access the database
* @return a DvbDatabase 
* @throws DatabaseException if a metadata service cannot be found
* @throws org.davic.mpeg.TuningException if tuning would be required to access a metadata service but this has been prohibited
*/
  public static org.dvb.tvanytime.metadata.DvbDatabase newInstance(boolean doNotTune
  ) throws org.dvb.tvanytime.metadata.DatabaseException, org.davic.mpeg.TuningException
  {return (null);}

/**
* Get an instance of a DvbDatabase carried on a specified DVB service with the specified 
* metadataServiceId.
* 
* <p>If the receiver does not have a DVB tuner a {@link DatabaseException} will be thrown.
* 
* <p>Applications can use the <code>doNotTune</code> parameter to specify that the tuning of a reserved tuner 
* should not be required to access the Database. In this case, an <code>org.davic.mpeg.TuningException</code> will 
* be thrown if the platform is not able to access the specified transport stream without tuning. If a DvbDatabase 
* is returned but subsequently becomes inaccessible without tuning a {@link DatabaseException} will be thrown 
* if access is attempted.
* 
* <p>If the <code>doNotTune</code> parameter is set to false and tuning is required to access the database then a 
* tuner will be reserved if one is available. If a tuner cannot be reserved then a <code>org.davic.mpeg.TuningException</code> 
* will be thrown.
* 
* @param service a DVB locator that points to the DVB service where a TV-Anytime 
* metadata service can be found
* @param metadataServiceId a value that identifies the required metadata service
* @param doNotTune true indicates that tuning must not be required to access the database
* @return a DvbDatabase 
* @throws DatabaseException if the specified metadata service cannot be found
* @throws org.davic.mpeg.TuningException if tuning would be required to access the specified service but this has been prohibited
*/
  public static org.dvb.tvanytime.metadata.DvbDatabase newInstance(
      org.davic.net.dvb.DvbLocator service, int metadataServiceId, 
	  boolean doNotTune
  ) throws org.dvb.tvanytime.metadata.DatabaseException, org.davic.mpeg.TuningException
  {return (null);}

/**
* Get an instance of a DvbDatabase where the platform chooses a service that can provide metadata
* for the given CRID authority.  
* 
* <p>If the receiver does not have a DVB tuner a {@link DatabaseException} will be thrown.
* 
* <p>Applications can use the <code>doNotTune</code> parameter to specify that the tuning of a reserved tuner 
* should not be required to access the database. In this case, an <code>org.davic.mpeg.TuningException</code> will be thrown if the platform is 
* unable to provide a DvbDatabase that can be accessed without tuning. If a DvbDatabase is returned but subsequently 
* becomes inaccessible without tuning a {@link DatabaseException} will be thrown if access is attempted.
* 
* <p>If the <code>doNotTune</code> parameter is set to false and tuning is required to access the database then a 
* tuner will be reserved if one is available. If a tuner cannot be reserved then a <code>org.davic.mpeg.TuningException</code> 
* will be thrown.
* 
* @param crid the authority field from the supplied CRID is used to decide 
* which metadata service to use.
* @param doNotTune true indicates that tuning must not be required to access the database
* @return a DvbDatabase for this service, 
* @throws DatabaseException if a metadata service cannot be found for the given CRID authority
* @throws org.davic.mpeg.TuningException if tuning would be required to access a metadata service but this has been prohibited
*/
  public static org.dvb.tvanytime.metadata.DvbDatabase newInstance(
      org.dvb.tvanytime.resolution.CRID crid,
	  boolean doNotTune
  ) throws org.dvb.tvanytime.metadata.DatabaseException, org.davic.mpeg.TuningException
  {return (null);}
  
  /**
  * Get an array listing all DvbDatabases that can provide metadata for the specified scope. This method may block 
  * for some time whilst accessing DVB-SI tables. 
  * 
  * <p>If the receiver does not have a DVB tuner a {@link DatabaseException} will be thrown.
  * 
  * <p>Applications can use the <code>doNotTune</code> parameter to restrict the returned databases to those 
  * that can be accessed without the tuning of a reserved tuner. In this case, an <code>org.davic.mpeg.TuningException</code> 
  * will be thrown if the platform is not able to provide any DvbDatabases that can be accessed without tuning.
  * If a DvbDatabase is returned that subsequently becomes inaccessible without tuning a {@link DatabaseException} 
  * will be thrown if access is attempted. If the <code>doNotTune</code> parameter is set to false then the returned 
  * databases will include those that would require the use of a reserved tuner but a tuner is not tuned or reserved.
  * 
  * @param scope the required scope of the DvbDatabases.
  * @param doNotTune true indicates that tuning must not be required to access the returned databases.
  * @return an array listing all DvbDatabases with the required scope that are signalled in DVB-SI. This will include 
  * all existing DVBDatabase instances where they exist and new instances where an existing instance does not exist.
  * @throws DatabaseException if no metadata services can be found for the specified scope.
  * @throws org.davic.mpeg.TuningException if no metadata services can be found that are accessible without 
  * tuning and this has been prohibited.
  */
  public static org.dvb.tvanytime.metadata.DvbDatabase[] getAvailableDatabases(
    DatabaseScope scope, 
	boolean doNotTune
  )  throws org.dvb.tvanytime.metadata.DatabaseException, org.davic.mpeg.TuningException
  {return (null);}
     
  /**
   * Get the list of available fragment types as signalled in the Metadata Descriptor associated with 
   * this metadata service. If the list is not available (i.e. the <code>fragment_types_flag</code> of the 
   * descriptor is set to '0') this method will return null.
   * 
   * @return a list of <code>fragment_type</code> values as defined in ETSI TS 102 323, or null.
   */
  public abstract int[] getAvailableFragmentTypes();

}


