package org.dvb.tvanytime.metadata;

/**
 * An iterator which allows applications to traverse metadata fragments in a {@link DatabaseQueryResult}.
 * Implementations which support java.util.ListIterator may use this as the parent interface.
 */
public interface ListIterator {

    /**
	 * Returns <code>true</code> if this list iterator has more elements when traversing the 
	 * list in the forward direction. (In other words, returns <code>true</code> if <code>next</code> would 
	 * return an element rather than throwing an exception.)
	 * 
	 * @return <code>true</code> if the list iterator has more elements when traversing the list in the forward direction.
	 */
    boolean hasNext();
	
	/**
	 * Returns <code>true</code> if this list iterator has more elements when traversing the 
	 * list in the reverse direction. (In other words, returns <code>true</code> if <code>previous</code> would 
	 * return an element rather than throwing an exception.)
	 * 
	 * @return <code>true</code> if the list iterator has more elements when traversing the list in the reverse direction.
	 */
    boolean hasPrevious();

    /**
     * Returns the next element in the list. This method may be called repeatedly to iterate through the list, 
     * or intermixed with calls to <code>previous</code> to go back and forth. (Note that alternating calls to <code>next</code> 
     * and <code>previous</code> will return the same element repeatedly.)
     * 
     * @return the next element in the list.
     * @throws <code>java.util.NoSuchElementException</code> if the iteration has no next element.
     */
    Object next();

    /**
     * Returns the index of the element that would be returned by a subsequent call to <code>next</code>. 
     * (Returns list size if the list iterator is at the end of the list.)
     * 
     * @return the index of the element that would be returned by a subsequent call to <code>next</code>, or 
     * list size if list iterator is at end of list.
     */
    int nextIndex();

    /**
     * Returns the previous element in the list. This method may be called repeatedly to iterate through the 
     * list backwards, or intermixed with calls to <code>next</code> to go back and forth. (Note that alternating calls to 
     * <code>next</code> and <code>previous</code> will return the same element repeatedly.)
     * 
     * @return the previous element in the list.
     * @throws <code>java.util.NoSuchElementException</code> if the iteration has no previous element.
     */
    Object previous();

    /**
     * Returns the index of the element that would be returned by a subsequent call to <code>previous</code>. 
     * (Returns -1 if the list iterator is at the beginning of the list.)
     * 
     * @return the index of the element that would be returned by a subsequent call to <code>previous</code>, or -1 if list iterator is at beginning of list.
     */
    int previousIndex();

}

