package org.dvb.tvanytime.metadata;

/**
* An interface for applications wishing to be informed when revised information becomes available from a metadata 
* service. 
* The scope of the information that is monitored for changes is defined by a {@link DatabaseQueryResult} that 
* was returned as the result of a metadata query. Only one of the two methods supported by the interface will ever 
* be called after which monitoring will cease. To obtain the revised metadata, the query which led to the 
* {@link DatabaseQueryResult} must be repeated. 
*/
public abstract interface MetadataChangedListener   {

/**
* This method is called when a change has occurred in a metadata service that is within the scope of the specified 
* DatabaseQueryResult. This method will only be called once, after which the monitoring of changes will cease.
* @param document the {@link DatabaseQueryResult} which defined the scope of the monitoring request.
*/
  public  abstract void metadataChanged(org.dvb.tvanytime.metadata.DatabaseQueryResult document) ;

  /**
  * This method is called when a request to monitoring of changes in a metadata service has failed or has been 
  * terminated. This method wll be called following a call to {@link DatabaseQueryResult#close()}.
  * @param document the {@link DatabaseQueryResult} which defined the scope of the monitoring request.
  * @param status a value that is set to <code>FAILED</code> or <code>TERMINATED</code>.
  */
    public  abstract void requestCancelled(org.dvb.tvanytime.metadata.DatabaseQueryResult document, int status) ;

    /**
     *   Value which indicates that the request to monitor changes has been refused. 
     */
    public static final int FAILED = 0;
    /**
     *   Value which indicates that the monitoring of changes has been terminated due to a resource conflict.
     */
    public static final int TERMINATED = 1;

}


