package org.dvb.tvanytime.metadata;

/**
* An interface for applications that wish to listen for changes to a {@link 
* DatabaseQueryResult}. 
*/
public abstract interface ResultListener   {

/**
* This method is called to inform a listener that an element has been added to a 
* DatabaseQueryResult.
* @param document the DatabaseQueryResult that has been affected  
* @param element the element that has been added. For example this 
* could be a ProgramInformation element which would signify that metadata 
* for a CRID has been added to the document. 
*/
  public  abstract void databaseResultAdded(
      org.dvb.tvanytime.metadata.DatabaseQueryResult document,
      org.dvb.xml.jdom.Element element
  ) ;

  /**
  * This method is called to inform a listener that all the callbacks arising from a GetMetadata or a 
  * GetSchedule request have been completed.
  * @param document The document that has been updated 
  * @param status an <code>int</code> value that indicate the success or  otherwise of the 
  * original request.
  */
    public  abstract void notifyFinished(
    	org.dvb.tvanytime.metadata.DatabaseQueryResult document,
        int status
    ) ;

    /**
     * The request has completed without errors. 
     */
    public static final int REQUEST_COMPLETED = 0;
    /**
     * The request has failed due to an error and the result is empty.
     */
    public static final int REQUEST_FAILED = 1;
    /**
     * Result is partially complete because the response was terminated due to an error. 
     */
    public static final int RESPONSE_INCOMPLETE = 2;
    /**
     * Request has completed without errors but the result has been truncated due to restrictions applied by the implementation. 
     */
    public static final int RESPONSE_TRUNCATED = 3;

}


