package org.dvb.tvanytime.metadata;

/**
 * Class which allows a specific table type to be requested in the QueryConstraints class.
 * 
 * An optional set of sort criteria can also be specified which allow particular 
 * fields in the table to be sorted in either ascending or descending order. 
 * 
 * @see QueryConstraints 
 * @author Chris Newell
 * @version 1.0
 *
 */
public class Table {

  /**
   * Construct a Table object.
   * @param table the name of this table (e.g. "ProgramInformationTable").
   */
  public Table(String table) {
  	
  }
   
  /**
   * Add a sort criteria for a particular fieldID. Several sort criteria can be requested by making a call for
   * each fieldID. However, the degree of sorting that can be achieved will be restricted by the capabilities 
   * of the implementation or the remote server.
   * 
   * <p>If more than one sort criteria is specified then they will be applied to the table in the order 
   * in which they were added. If the same fieldID is specified more than once then the previous value of 
   * <code>isAscendingOrder</code> will be overwritten but the order in which the sort criteria will be applied is 
   * unaffected.
   * 
   * @param fieldID the fieldID of the field which is to be sorted.
   * @param isAscendingOrder <code>true</code> if the sort is to applied in ascending order, <code>false</code> if descending order 
   * is to be applied.  
   */
  public void addSortCriteria(String fieldID, boolean isAscendingOrder) {
  	
  }

  /**
   * Get the name of this table. (e.g. "ProgramInformationTable")
   * @return the table name
   */
  public String getName() {
  	return new String();
  }
  
  /**
   * Get an array listing the fieldIDs of the sort criteria. The order in which the fieldIDs are listed will 
   * correspond to order in which the sort criteria were requested. 
   * @return an array of FieldID strings
   */
  public String[] getSortCriteriaFieldIDs() {
  	return new String[0];
  }

  /**
   * Get an array listing the orderings of the sort criteria. The order in which the orderings are listed will 
   * correspond to order in which the sort criteria were requested.
   * @return an array of boolean isAscendingOrder fields.
   * 
   */
  public boolean[] getSortCriteriaOrderings() {
  	return new boolean[0];
  }
  
}

