package org.dvb.tvanytime.metadata.ip;

import org.dvb.tvanytime.metadata.Database;
import org.dvb.tvanytime.metadata.DatabaseException;
import org.dvb.tvanytime.metadata.DatabaseQueryResult;
import org.dvb.xml.jdom.Element;


/**
* Class providing access to Broadband Content Guides whose location is signalled by IP-based Service
* Discovery & Selection information.
*  
*/
public abstract class BCGDiscovery {

/**
* This constructor is provided for implementations and should not be used by GEM applications.
*/
  public BCGDiscovery() {}
  
  /**
   * Get an array of Databases that can provide metadata for the specified CRID Authority.
   * @param crid the authority field from the supplied CRID is used to decide which metadata servers to return.
   * The CRID authority should be matched against Metadata Pointer Descriptors in Resolution Provider Notification Tables
   * delivered by IP-based Service Discovery & Selection information or in a DVB service.
   * 
   * @return an array of type {@link  org.dvb.tvanytime.metadata.Database}. Each object in the returned array will be an instance of 
   * either {@link MulticastDatabase}, {@link HTTPDatabase} or {@link  org.dvb.tvanytime.metadata.IPDatabase}.
   * @throws DatabaseException if no metadata services can be found for the specified scope
   */
  public static org.dvb.tvanytime.metadata.Database[] getAvailableDatabases(org.dvb.tvanytime.resolution.CRID crid)  throws org.dvb.tvanytime.metadata.DatabaseException {
    return (null); 
  }
  
  /**
   * Get an array of Databases that can provide metadata for the specified service provider. 
   * 
   * @param serviceProviderDomainName a String representing the domain name of a service provider. This should be matched 
   * against the TargetProvider fields in Broadband Content Guide Discovery Records delivered by IP-based Service 
   * Discovery & Selection information.
   * @return an array of type {@link  org.dvb.tvanytime.metadata.Database}. Each object in the returned array will be an instance of 
   * either {@link MulticastDatabase}, {@link HTTPDatabase} or {@link  org.dvb.tvanytime.metadata.IPDatabase}.
   * @throws DatabaseException if no metadata services can be found for the specified scope
   */
  public static org.dvb.tvanytime.metadata.Database[] getAvailableDatabases(String serviceProviderDomainName)  throws org.dvb.tvanytime.metadata.DatabaseException {
    return (null);
  }  
  
  
  /**
   * Get an array of Databases from the specified BCG provider. 
   * 
   * @param BCGProviderName a String representing the domain name of the BCG provider. This should be matched 
   * against the BCGProviderName in Broadband Content Guide Discovery Records delivered by IP-based Service 
   * Discovery & Selection information.
   * @return an array of type {@link  org.dvb.tvanytime.metadata.Database}. Each object in the returned array will be an instance of 
   * either {@link MulticastDatabase}, {@link HTTPDatabase} or {@link  org.dvb.tvanytime.metadata.IPDatabase}.
   * @throws DatabaseException if no metadata services can be found for the specified scope
   */
  public static org.dvb.tvanytime.metadata.Database[] getAvailableDatabasesByProvider(String BCGProviderName)  throws org.dvb.tvanytime.metadata.DatabaseException {
    return (null);
  }  
  
  /**
   * Get an array of Databases that can provide metadata for the specified service. 
   *
   * @param locator a locator representing a service. This should be matched against entries in IP-based Service Discovery & Selection
   * information to find Broadband Content Guides identified by ServiceDescriptionLocation and ServicesDescriptionLocation fields.
   * 
   * @return an array of type {@link  org.dvb.tvanytime.metadata.Database}. Each object in the returned array will be an instance of 
   * either {@link MulticastDatabase}, {@link HTTPDatabase} or {@link  org.dvb.tvanytime.metadata.IPDatabase}.
   * @throws DatabaseException if no metadata services can be found for the specified scope
   */
  public static org.dvb.tvanytime.metadata.Database[] getAvailableDatabases(javax.tv.locator.Locator locator)  throws org.dvb.tvanytime.metadata.DatabaseException  {
    return (null);
  }
  
  /**
  * Get an instance of a Broadband Content Guide where the platform chooses the host.
  * 
  * @return a Database 
  * @throws DatabaseException if a metadata service cannot be found
  */
  public static org.dvb.tvanytime.metadata.Database getDatabase() 
    throws org.dvb.tvanytime.metadata.DatabaseException {
    return (null);
  }
  
  

}
