package org.dvb.tvanytime.resolution;

/**
* Interface implemented by classes wishing to use a resolution response. The 
* function is called when the resolution is completed or all attempts at 
* resolving the CRID have been exhausted. 
*/
public abstract interface ResolutionListener   {

/**
* This method is called to indicate that a valid resolution response has been
* obtained. Implementations should note that this callback blocks the response thread 
* so callbacks corresponding to a single request are guaranteed 
* synchronous. This is not the case if more than one request is made before 
* the last callback has returned from the first request. 
* @param rr The resulting ResolutionResponse object 
*/
  public  abstract void resolutionCallback(
      org.dvb.tvanytime.resolution.ResolutionResponse rr
  ) ;

  /**
  * This method is called to indicate that a resolution request has failed. 
  * Implementations should note that this callback blocks the response thread 
  * so callbacks corresponding to a single request are guaranteed 
  * synchronous. This is not the case if more than one request is made before 
  * the last callback has returned from the first request. 
  * @param crid the CRID that was to be resolved
  * @param reason a value that is set to <code>UNKNOWN_CRID_AUTHORITY</code> or <code>ACCESS_ERROR</code>
  */
    public  abstract void resolutionFailed(
        org.dvb.tvanytime.resolution.CRID crid, int reason
    ) ;
   

    /**
     * Value which indicates that the CRID authority of the CRID is not supported by the specified resolution sources.
     */
    public static final  int UNKNOWN_CRID_AUTHORITY = 0;
      
    /**
     * Value which indicates that resolution has failed due to an error condition preventing access to the specified resolution sources.
     */
    public static final  int ACCESS_ERROR = 1;
            
}


