package org.dvb.xml.jdom;

/**
* Interface that represents one XML Element.
*/
public abstract interface Element  extends org.dvb.xml.jdom.Node {

/**
* Get the list of XML Schema namespaces that are available to this element. 
* @return an array of available namespaces (excluding the element's own 
* namespace) 
*/
  public  abstract org.dvb.xml.jdom.Namespace[] getAdditionalNamespaces(
  ) ;

/**
* Check to see if this is the root element. (i.e. one with no parent) 
* @return true if this is the root element. 
*/
  public  abstract boolean isRootElement(
  ) ;

/**
* Returns an enumeration containing all Elements / Attributes of the given 
* field. The field name is based on the TV Anytime defined field ID list from 
* SP006. 
* @param fieldName the name of the field to search for (e.g. "Title") 
* @return an enumeration of of selected nodes, which will be instances of the 
* Element or Attribute interfaces. If no matches are found, an empty 
* enumerator is returned. 
*/
  public  abstract java.util.Enumeration findField(
      java.lang.String fieldName
  ) ;

/**
* Returns the first String representation for the given field. The field name 
* is based on the TV Anytime defined field ID list from SP006. 
* @param fieldName the name of the field to search for (e.g. "Title") 
* @return the first String representation of specified field or null if the 
* field cannot be found. 
*/
  public  abstract java.lang.String findFirstField(
      java.lang.String fieldName
  ) ;

/**
* Get an array of all the children of this element. 
* @return all the Elements that are children of this element 
*/
  public  abstract org.dvb.xml.jdom.Element[] getChildren(
  ) ;

/**
* Get an array of all the children of this element that have the given name, 
* ignoring XML namespaces. 
* @param name The name of the element 
* @return all the Elements that are children of this element, that have this 
* given name 
*/
  public  abstract org.dvb.xml.jdom.Element[] getChildren(
      java.lang.String name
  ) ;

/**
* Get an array of all the children of this element that have the given name 
* and belong to the given namespace. 
* @param name The name of the element 
* @param ns The namespace that the name belongs to 
* @return all the Elements that are children of this element that have the 
* name specificed, within the specified namespace 
*/
  public  abstract org.dvb.xml.jdom.Element[] getChildren(
      java.lang.String name,
      org.dvb.xml.jdom.Namespace ns
  ) ;

/**
* Get the first child of this element that has the given name, ignoring XML 
* namespaces.
* @param name The name of the element 
* @return the first Element that is a child of this element that has the name 
* specificed, or null if no suitable Element can be found 
*/
  public  abstract org.dvb.xml.jdom.Element getChild(
      java.lang.String name
  ) ;

/**
* Get the first child of this element that has the given name and belongs to 
* the given namespace. 
* @param name The name of the element 
* @param ns The namespace that the name belongs to 
* @return the first Element that is a child of this element that has the name 
* specificed, within the specified namespace, or null if no suitable Element 
* can be found 
*/
  public  abstract org.dvb.xml.jdom.Element getChild(
      java.lang.String name,
      org.dvb.xml.jdom.Namespace ns
  ) ;

/**
* Get all the attributes of this element.
* @return an array of all the attributes of this element. If this element has 
* no attributes, an empty array is returned 
*/
  public  abstract org.dvb.xml.jdom.Attribute[] getAttributes(
  ) ;

/**
* Get the named attribute of this element, ignoring XML namespaces.
* @param name The name of the attribute 
* @return the Attribute with the specified name, or null if not found 
*/
  public  abstract org.dvb.xml.jdom.Attribute getAttribute(
      java.lang.String name
  ) ;

/**
* Get the named attribute of this element, using an XML namespace.
* @param name The name of the attribute 
* @param ns The namespace that the name belongs to 
* @return the Attribute with the specified name, or null if not found 
*/
  public  abstract org.dvb.xml.jdom.Attribute getAttribute(
      java.lang.String name,
      org.dvb.xml.jdom.Namespace ns
  ) ;
  
  /**
   * Indicates whether this Element has an unknown extension.
   *
   * @see #getUnknownElementContent
   * @return true if this Element has an unknown extension, false otherwise
   */
  public boolean hasUnknownElementContent();

  /**
   * Get the UnknownElementContent carried by this Element.
   * This method will return null if there is no unknown extension data.
   * 
   * The <code>readBits(int)</code> method of the {@link UnknownElementContent} object returned by this method
   * will access a binary stream carrying one or more ElementContentChunks.
   *
   * @see #hasUnknownElementContent
   * @return an UnknownElementContent object carrying the extension data or null. 
   */
  public UnknownElementContent getUnknownElementContent();
  
}


