package org.dvb.xml.jdom;

/**
 * Interface that provides access to Unknown Element Content corresponding to unknown schemas. 
 */
public interface UnknownElementContent {
	
  /**
   * Read a specified number of bits from the binary data of this
   * UnknownElementContent.
   *
   * @param n the number of bits to read. This must be a value greater than
   * zero and less than or equal to 32.
   *
   * @return a value where the LSBs contain the required bits.
   *
   * @throws java.lang.IllegalArgumentException if the supplied argument
   * is outside the permitted range. 
   * @throws java.lang.IndexOutOfBoundsException if the requested number of
   * bits exceeds the number remaining to be read. 
   *
   */
  public int readBits(int n);

  /**
   * Tests whether there is more binary data to read from this
   * UnknownElementContent.
   *
   * @return true if there are more bits to be read, false otherwise.
   */
  public boolean hasMoreBits();

  /**
   * Get the strings associated with this UnknownElementContent.
   * The method will return null if there are no strings referenced by this UnknownElementContent.
   *
   * @return an array of strings or null. The strings in the array will be in the same order that 
   * they are referenced by the UnknownElementContent.
   */
  public String[] getStrings();
  
  /**
   * Get the <code>TVA-init</code> structure associated with this UnknownElementContent.
   *
   * @return a byte array carrying the <code>TVA-init</code> structure.
   */
  public byte[] getTVAInit();

  /**
   * Get the URI of the schema referenced by the specified schemaIdentifier. The URIs are listed in the 
   * <code>decoderInit</code> information carried by the <code>TVA-init</code> structure.
   *
   * @param schemaIdentifier the zero-based index of the schema within the <code>decoderInit</code> information
   * @return the URI of the schema
   */
  public String getSchemaURI(int schemaIdentifier);

  /**
   * Get the number of schema listed in the <code>TVA-init</code> structure. The
   * number of schema is signalled in the <code>decoderInit</code> information.
   *
   * @return the number of schema.
   */
  public int getNumberOfSchemas();

  /**
   * Get names of the schemas listed in the <code>TVA-init</code> structure. The
   * schemas are listed in the <code>decoderInit</code> information.
   *
   * @return an array listing all the schemas
   */
  public String[] getSchemas();

}




