package org.oipf.download;

import java.io.RandomAccessFile;

/**
 * 
 * Represents a content download to be performed by an application.
 * 
 * Requests of this type are handled totally by an application. They are
 * 
 * created in the PENDING_NO_CONFLICT_STATE. The application handling the
 * 
 * request is responsible for downloading the content and all resulting
 * 
 * state changes.
 * <p>
 * 
 * Requests of this type shall always be visible to the application specified
 * 
 * when the corresponding ApplicationDownloadSpec was created regardless of
 * 
 * recording request specific security attributes.
 * 
 * The methods defined in this class shall always fail with a
 * ApplicationDownloadException
 * 
 * if called by any application other than the one specified when
 * 
 * the corresponding ApplicationDownloadSpec was created.
 */

public interface ApplicationDownloadRequest extends org.ocap.shared.dvr.LeafRecordingRequest {

   /**
    * 
    * Return a file to which downloaded data can be written and from
    * 
    * which downloaded data can be read.
    * 
    * @return a File
    * 
    * @throws ApplicationDownloadException
    *            if the caller is not permitted
    * 
    *            to call this method as defined above
    */

   RandomAccessFile getFile() throws ApplicationDownloadException;

   /**
    * 
    * Set the state of the download.
    * 
    * @param state
    *           the new state of the recording
    * 
    * @throws ApplicationDownloadException
    *            if the caller is not permitted
    * 
    *            to call this method as defined above
    */

   public void setState(int state);

   /**
    * 
    * Set the reason to use for the exception returned by getFailedException.
    * 
    * The reason must be one valid for the constructor of
    * 
    * RecordingFailedException.
    * 
    * @param reason
    *           the reason to use when constructing a
    * 
    *           RecordingFailedException
    */

   public void setFailedReason(int reason);

}